.. _decoding:

=================================================
Decoding and MVPA: predicting from brain images
=================================================

Decoding consists in predicting external variables such as behavioral or
phenotypic variables from brain image. It can be useful for diagnostic of
prognosis, or to probe the information content of brain activity images.

These are `Supervised learning
<https://en.wikipedia.org/wiki/Supervised_learning>`_ tasks, focused on
predicting an output value.

|

.. toctree::

   decoding_intro.rst
   estimator_choice.rst
   frem.rst
   space_net.rst
   searchlight.rst
   going_further.rst
